# AutoRepo

### AutoRepo is a simple, cli-based tool for automating the creation of github repositories.

<br/><br/>

# Installation

- Run the following command to install AutoRepo to your PC

```
$ pip install autorepo
```

<br/><br/>

# Usage

- After the installation is complete, you can run the following command to start AutoRepo (this will print the help message):

```
$ repo
```

- Using any command (displayed in the help message) requires you to first be logged in to your github account using an access token (this is a one-time thing). You can generate an access token by following the instructions here: <a href="https://help.github.com/articles/creating-a-personal-access-token-for-the-command-line/">https://help.github.com/articles/creating-a-personal-access-token-for-the-command-line/</a>

```
$ repo --login
```

Or

```
$ repo -l
```
